# Python imports

# Lib imports
import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk

# Application imports



class BottomButtonBox(Gtk.Box):
    def __init__(self):
        super(BottomButtonBox, self).__init__()

        self._setup_styling()
        self._setup_signals()
        self._subscribe_to_events()
        self._load_buttons()

        self.show()


    def _setup_styling(self):
        ctx = self.get_style_context()
        ctx.add_class("bottom-button-box")

        self.set_property("halign", Gtk.Align.END)

    def _setup_signals(self):
        ...

    def _subscribe_to_events(self):
        ...

    def _load_buttons(self):
        self.initialize_btn     = Gtk.Button(label = "Initialize Message")
        self.initialized_btn    = Gtk.Button(label = "Initialized Message")
        self.notification_btn   = Gtk.Button(label = "Send Notification")
        self.request_btn        = Gtk.Button(label = "Send Request")
        self.full_init_btn      = Gtk.Button(label = "Full Init")
        self.start_stop_lsp_btn = Gtk.Button(label = "LSP")
        self.start_stop_lsp_btn.running = False

        self.initialize_btn.connect("clicked", self.send_initialize_message)
        self.initialized_btn.connect("clicked", self.send_initialized_message)
        self.notification_btn.connect("clicked", self.send_notification)
        self.request_btn.connect("clicked", self.send_request)
        self.start_stop_lsp_btn.connect("clicked", self.start_stop_lsp)
        self.full_init_btn.connect("clicked", self.full_init)

        self.start_stop_lsp_btn.show()
        self.full_init_btn.show()

        for child in [
            self.initialize_btn,
            self.initialized_btn,
            self.notification_btn,
            self.request_btn,
            self.start_stop_lsp_btn,
            self.full_init_btn
        ]:
            self.add(child)
            # self.set_child_secondary(child, True)
            child.set_always_show_image(True)
            child.set_image( Gtk.Image.new_from_icon_name("gtk-media-play", Gtk.IconSize.BUTTON) )

        self.start_stop_lsp_btn.set_image( Gtk.Image.new_from_icon_name("gtk-media-play", Gtk.IconSize.BUTTON) )
        self.full_init_btn.set_image( Gtk.Image.new_from_icon_name("gtk-media-play", Gtk.IconSize.BUTTON) )

    def send_initialize_message(self, button, eve = None):
        button.hide()
        self.initialized_btn.show()
        self.get_parent().send_initialize_message()

    def send_initialized_message(self, button, eve = None):
        self.initialize_btn.hide()
        self.initialized_btn.hide()
        self.notification_btn.show()
        self.request_btn.show()

        self.get_parent().send_initialized_message()

    def send_notification(self, button, eve = None):
        children = self.get_children()
        self.get_parent().button_send_notification()

    def send_request(self, button, eve = None):
        children = self.get_children()
        self.get_parent().button_send_request()

    def start_stop_lsp(self, button, eve = None):
        if not button.running:
            button.running = True

            self.initialize_btn.show()
            self.full_init_btn.hide()

            button.set_image( Gtk.Image.new_from_icon_name("gtk-media-stop", Gtk.IconSize.BUTTON) )
        else:
            self.rest_buttons()

        self.get_parent().start_stop_lsp()

    def full_init(self, button, eve = None):
        button.hide()
        self.start_stop_lsp(self.start_stop_lsp_btn)

        if not hasattr(self.get_parent(), "lsp_process"):
            self.rest_buttons()
            return

        self.send_initialize_message(self.initialize_btn)
        self.send_initialized_message(self.initialized_btn)

    def rest_buttons(self):
        self.start_stop_lsp_btn.running = False

        self.initialize_btn.hide()
        self.initialized_btn.hide()
        self.notification_btn.hide()
        self.request_btn.hide()
        self.full_init_btn.show()

        self.start_stop_lsp_btn.set_image( Gtk.Image.new_from_icon_name("gtk-media-play", Gtk.IconSize.BUTTON) )